# pyliteconf

Библиотека для создание конфигурационных файлов из *.py файлов </br>
Огромный недостаток прочих решений в том, что не возможно прыгать к определениям конфигурационных файлов. 

## Цель 
Цель данной библиотеки максимально раскрыть возможность питона в написании файлов конфигурации и удобной работы с ними в питоне.